%define pkg       squid
%define ver       3.5.12
%define maj       %(echo %{ver} | cut -d'.' -f1)
%define min       %(echo %{ver} | cut -d'.' -f2)
%define pkgid     %{maj}
%define pkgstr    %{pkg}%{pkgid}

%define sel_modn  selinux-policy-addon
%define sel_modv  0.2.8


Summary:          The Squid proxy caching server
Name:             %{pkgstr}
Version:          %{ver}
Release:          1%{?dist}%{?pext}
License:          GPL
Group:            System Environment/Daemons
Source0:          http://www.squid-cache.org/Versions/v%{maj}/%{maj}.%{min}/%{pkg}-%{ver}.tar.xz
Source1:          %{pkg}.init
Source2:          %{pkg}.logrotate
Source3:          %{pkg}.sysconfig
Source4:          %{pkg}.pam
Patch0:           %{pkg}-3.5.12-paths.patch
Patch1:           %{pkg}-3.5.12-config.patch
Patch2:           %{pkg}-3.5.12-cachemgr.patch
Patch10:          http://www.squid-cache.org/Versions/v3/3.5/changesets/squid-3.5-13962.patch
Patch11:          http://www.squid-cache.org/Versions/v3/3.5/changesets/squid-3.5-13963.patch
URL:              http://www.squid-cache.org/
Buildroot:        %{_tmppath}/%{name}-%{version}-%{release}-root-%(%{__id_u} -n)
Vendor:           The Squid Software Foundation <squid-bugs@squid-cache.org>
Requires:         %{_bindir}/certutil
Requires(pre):    %{_sbindir}/groupadd %{_sbindir}/useradd
Requires(post):   /sbin/chkconfig
Requires(preun):  /sbin/chkconfig /sbin/service
Requires(postun): /sbin/service
Conflicts:        %{pkg} %{pkg}2
BuildRequires:    cyrus-sasl-devel expat-devel db4-devel
BuildRequires:    krb5-devel libcap2-devel libecap-devel >= 1.0
BuildRequires:    libxml2-devel openldap-devel openssl10-devel
BuildRequires:    pam-devel pkgconfig gcc44-c++
BuildArch:        i486 x86_64

%description
Squid is a high-performance proxy caching server for Web clients, supporting
FTP, Gopher and HTTP data objects. Unlike traditional caching software, Squid
handles all requests in a single, non-blocking, I/O-driven process. It keeps
metadata and especially hot objects cached in RAM, caches DNS lookups, supports
non-blocking DNS lookups, and implements negative caching of failed requests.


%package          selinux
Summary:          SELinux support for Squid
Group:            System Environment/Base
Requires:         %{name} = %{version}-%{release}
Requires:         %{sel_modn} >= %{sel_modv}
Requires(post):   /sbin/restorecon %{_sbindir}/selinuxenabled /sbin/fixfiles

%description      selinux
This package enables Squid to work with SELinux.


%prep
%setup -q -n %{pkg}-%{ver}

# Local patches
%patch0 -p1
%patch1 -p1
%patch2 -p1

# Upstream patches
%patch10 -p0
%patch11 -p0

# Fix path to Perl
for FILE in `find . -type f -name "*.pl" -exec fgrep -l "/bin/perl" {} \;`; do
  %{__perl} -i -pe 's+(/.*)?/bin/perl+%{__perl}+g' ${FILE}
done

# Fix patch to Cache Manager
for FILE in tools/httpd.conf; do
  %{__perl} -i -pe 's+LIBEXECDIR+%{_libdir}/%{pkg}+g' ${FILE}
done

# Prepare docs
%{__mkdir_p} doc/helpers/basic/{DB,RADIUS,SASL,SMB,SMB_LM}
%{__mkdir_p} doc/helpers/external/{LDAP_group,file_userip,kerberos_ldap_group}
%{__mkdir_p} doc/helpers/log_daemon/DB
%{__mkdir_p} doc/helpers/negotiate/kerberos

%{__cp} helpers/basic_auth/DB/passwd.sql  doc/helpers/basic/DB
%{__cp} helpers/basic_auth/RADIUS/README  doc/helpers/basic/RADIUS
%{__cp} helpers/basic_auth/SASL/*.conf    doc/helpers/basic/SASL
%{__cp} helpers/basic_auth/SASL/*.pam     doc/helpers/basic/SASL
%{__cp} helpers/basic_auth/SMB/ChangeLog  doc/helpers/basic/SMB
%{__cp} helpers/basic_auth/SMB_LM/*.html  doc/helpers/basic/SMB_LM

%{__cp} helpers/external*/LDAP*/ChangeLog doc/helpers/external/LDAP_group
%{__cp} helpers/external*/file*/*.conf    doc/helpers/external/file_userip
%{__cp} helpers/external*/kerb*/README    doc/helpers/external/kerberos_ldap_group

%{__cp} helpers/log_daemon/DB/doc/*.sql   doc/helpers/log_daemon/DB

%{__cp} helpers/negotiate*/kerb*/README   doc/helpers/negotiate/kerberos


%build
export CC="gcc44"
export CXX="g++44"

%configure \
	--sysconfdir=%{_sysconfdir}/%{pkg}                    \
	--libexecdir=%{_libdir}/%{pkg}                        \
	--datadir=%{_datadir}/%{pkg}                          \
	--disable-arch-native                                 \
	--enable-shared                                       \
	--enable-build-info="Build id: %{version}-%{release}" \
	--enable-disk-io                                      \
	--enable-storeio="aufs,diskd,rock,ufs"                \
	--enable-removal-policies="heap,lru"                  \
	--enable-icmp                                         \
	--enable-delay-pools                                  \
	--enable-esi                                          \
	--enable-ecap                                         \
	--enable-wccp                                         \
	--enable-wccpv2                                       \
	--enable-kill-parent-hack                             \
	--enable-eui                                          \
	--enable-htcp                                         \
	--enable-forw-via-db                                  \
	--enable-cache-digests                                \
	--enable-http-violations                              \
	--enable-linux-netfilter                              \
	--enable-follow-x-forwarded-for                       \
	--disable-ident-lookups                               \
	--enable-ssl-crtd                                     \
	--enable-auth                                         \
	--enable-auth-basic                                   \
	--enable-auth-digest                                  \
	--enable-auth-negotiate                               \
	--enable-auth-ntlm                                    \
	--enable-log-daemon-helpers                           \
	--enable-external-acl-helpers                         \
	--enable-storeid-rewrite-helpers                      \
	--enable-url-rewrite-helpers                          \
	--enable-stacktraces                                  \
	--enable-x-accelerator-vary                           \
	--enable-zph-qos                                      \
	--with-default-user=%{pkg}                            \
	--with-logdir=%{_localstatedir}/log/%{pkg}            \
	--with-pidfile=%{_localstatedir}/run/%{pkg}.pid       \
	--with-swapdir=%{_localstatedir}/cache/%{pkg}         \
	--with-dl                                             \
	--with-pthreads                                       \
	--with-aio                                            \
	--with-openssl=%{_prefix}                             \
	--with-large-files                                    \
	--with-libcap                                         \
	--with-filedescriptors=32768

%{__make} %{?_smp_mflags}


%install
[ -n "${RPM_BUILD_ROOT}" -a "${RPM_BUILD_ROOT}" != "/" ] && %{__rm} -rf ${RPM_BUILD_ROOT}
%{__mkdir_p} ${RPM_BUILD_ROOT}%{_initrddir}
%{__mkdir_p} ${RPM_BUILD_ROOT}%{_sysconfdir}/{httpd/conf.d,logrotate.d,pam.d,sysconfig}
%{__mkdir_p} ${RPM_BUILD_ROOT}%{_prefix}
%{__mkdir_p} ${RPM_BUILD_ROOT}%{_datadir}/snmp/mibs
%{__mkdir_p} ${RPM_BUILD_ROOT}%{_localstatedir}/{cache,log,spool}/%{pkg}

%{__make} \
	DESTDIR=${RPM_BUILD_ROOT} \
	install

%{__install} -m 0755 %{SOURCE1} ${RPM_BUILD_ROOT}%{_initrddir}/%{pkg}
%{__install} -m 0644 %{SOURCE2} ${RPM_BUILD_ROOT}%{_sysconfdir}/logrotate.d/%{pkg}
%{__install} -m 0644 %{SOURCE3} ${RPM_BUILD_ROOT}%{_sysconfdir}/sysconfig/%{pkg}

%{__install} -m 0644 %{SOURCE4} ${RPM_BUILD_ROOT}%{_sysconfdir}/pam.d/%{pkg}

%{__chmod}   u+s                ${RPM_BUILD_ROOT}%{_libdir}/%{pkg}/pinger

pushd src
%{__install} -m 0644 mib.txt    ${RPM_BUILD_ROOT}%{_datadir}/snmp/mibs/SQUID-MIB.txt
popd

pushd tools
%{__install} -m 0644 httpd.conf ${RPM_BUILD_ROOT}%{_sysconfdir}/httpd/conf.d/%{pkg}.conf
popd

# Cleanup
%{__rm}      -f                 ${RPM_BUILD_ROOT}%{_bindir}/Run{Accel,Cache}
%{__rm}      -f                 ${RPM_BUILD_ROOT}%{_datadir}/%{pkg}/mib.txt


%pre
if ! getent group  %{pkg} >/dev/null 2>&1; then
  /usr/sbin/groupadd -r -g 23 %{pkg}
fi
if ! getent passwd %{pkg} >/dev/null 2>&1; then
  /usr/sbin/useradd  -r -u 23 -g %{pkg}   \
	-d %{_localstatedir}/spool/%{pkg} \
	-c "SQUID Service user"           \
	-s /sbin/nologin %{pkg}
fi
exit 0			# Always pass


%post
/sbin/chkconfig --add %{pkg}

%post selinux
if /usr/sbin/selinuxenabled && [ -e /selinux/policyvers ]; then
  /sbin/fixfiles   -R %{name} restore
# /sbin/restorecon -R %{_localstatedir}/cache/%{pkg}
  /sbin/restorecon -R %{_localstatedir}/log/%{pkg}
  /sbin/restorecon -R %{_localstatedir}/spool/%{pkg}
fi


%preun
if [ $1 -eq 0 ]; then	# Remove
  /sbin/service %{pkg} stop >/dev/null 2>&1
  /sbin/chkconfig --del %{pkg}
fi


%postun
if [ $1 -ge 1 ]; then	# Upgrade
  /sbin/service %{pkg} condrestart >/dev/null 2>&1 || :
fi


%clean
[ -n "${RPM_BUILD_ROOT}" -a "${RPM_BUILD_ROOT}" != "/" ] && %{__rm} -rf ${RPM_BUILD_ROOT}


%files
%defattr(-,root,root)
%doc CONTRIBUTORS COPY* CREDITS ChangeLog INSTALL QUICK*
%doc README RELEASENOTES* SPONSORS doc/*.txt doc/helpers
%{_initrddir}/%{pkg}
%config(noreplace) %{_sysconfdir}/logrotate.d/%{pkg}
%config(noreplace) %{_sysconfdir}/sysconfig/%{pkg}
%config(noreplace) %{_sysconfdir}/httpd/conf.d/%{pkg}.conf
%config(noreplace) %{_sysconfdir}/pam.d/%{pkg}
%dir %{_sysconfdir}/%{pkg}
%config(noreplace) %{_sysconfdir}/%{pkg}/cachemgr.conf
%config(noreplace) %{_sysconfdir}/%{pkg}/errorpage.css
%config(noreplace) %{_sysconfdir}/%{pkg}/mime.conf
%attr(640,root,%{pkg}) %config(noreplace) %{_sysconfdir}/%{pkg}/squid.conf
%{_sysconfdir}/%{pkg}/*.default
%{_sysconfdir}/%{pkg}/*.documented
%{_bindir}/purge
%{_bindir}/squidclient
%{_libdir}/%{pkg}
%{_sbindir}/%{pkg}
%config(noreplace) %{_datadir}/snmp/mibs/SQUID-MIB.txt
%config(noreplace) %{_datadir}/%{pkg}
%{_mandir}/man1/*.1*
%{_mandir}/man8/*.8*
%attr(750,%{pkg},%{pkg}) %dir %{_localstatedir}/cache/%{pkg}
%attr(750,%{pkg},%{pkg}) %dir %{_localstatedir}/log/%{pkg}
%attr(750,%{pkg},%{pkg}) %dir %{_localstatedir}/spool/%{pkg}

%files selinux
%defattr(-,root,root)


%changelog
* Sat Dec 19 2015 Peter Pramberger <peterpramb@member.fsf.org> - 3.5.12-1
- New version (3.5.12)

* Mon Sep 17 2012 Peter Pramberger <peterpramb@member.fsf.org> - 3.2.1-1
- New version (3.2.1)
- Renamed package from testing/squid32 to squid3

* Fri May 04 2012 Peter Pramberger <peterpramb@member.fsf.org> - 3.2.0.17-1
- New version (3.2.0.17)

* Tue Mar 20 2012 Peter Pramberger <peterpramb@member.fsf.org> - 3.2.0.16-1
- New version (3.2.0.16)

* Wed Dec 28 2011 Peter Pramberger <peterpramb@member.fsf.org> - 3.2.0.14-1
- New version (3.2.0.14)

* Fri Oct 21 2011 Peter Pramberger <peterpramb@member.fsf.org> - 3.2.0.13-1
- New version (3.2.0.13)

* Mon Oct 10 2011 Peter Pramberger <peterpramb@member.fsf.org> - 3.2.0.12-2
- Disabled host header verification in forward mode until the implementation
  is fixed to not affect legitimate services anymore (bug #3325, #3367)
- Added fix for bug #3355

* Sat Sep 17 2011 Peter Pramberger <peterpramb@member.fsf.org> - 3.2.0.12-1
- New version (3.2.0.12)

* Fri Sep 02 2011 Peter Pramberger <peterpramb@member.fsf.org> - 3.2.0.11-1
- New version (3.2.0.11)

* Mon Aug 15 2011 Peter Pramberger <peterpramb@member.fsf.org> - 3.2.0.10-1
- Initial build
